cwEPR
=====

The cwEPR package provides tools for handling experimental data obtained using continuous-wave EPR (cwEPR) spectroscopy and is derived from the `ASpecD framework <https://www.aspecd.de/>`_.


Installation
------------

Install the package by running::

    pip install cwepr


Contribute
----------

- Source Code: https://github.com/tillbiskup/cwepr


Support
-------

If you are having issues, please contact the package authors via GitHub and/or file a bug report there.


License
-------

The project licensed under the BSD license.

